@@ -9,7 +9,7 @@ def run_command(command):
     """Utility function to run a shell command."""
     try:
         result = subprocess.run(command, check=True, shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE, text=True)
-        return result.stdout
+        return result.stdout, result.stderr
     except subprocess.CalledProcessError as e:
         print(f"Error executing {command}: {e.stderr}")
         exit(1)
@@ -29,46 +29,58 @@ def run_mq_command(mq_command):
     os.chmod(script_file_path, 0o755)
     print(f"Running script:\n{script_content}")  # Debugging information
     try:
-        output = run_command(f"/bin/bash {script_file_path}")
+        output, error = run_command(f"/bin/bash {script_file_path}")
     finally:
         os.remove(script_file_path)
-    return output
+    return output, error
 
 def list_queue_managers(args):
     """List all queue managers."""
-    output = run_mq_command("dspmq")
+    output, error = run_mq_command("dspmq")
     print(output)
+    if error:
+        print(f"Error: {error}")
 
 def create_queue_manager(args):
     """Create a new queue manager."""
-    output = run_mq_command(f"/opt/mqm/bin/crtmqm {args.name} && /opt/mqm/bin/strmqm {args.name}")
+    output, error = run_mq_command(f"/opt/mqm/bin/crtmqm {args.name} && /opt/mqm/bin/strmqm {args.name}")
     print(f"Queue manager {args.name} created and started.\n{output}")
+    if error:
+        print(f"Error: {error}")
 
 def create_queue(args):
     """Create a queue in the specified queue manager."""
     mqsc_commands = f"""
     DEFINE QLOCAL('{args.queue_name}') REPLACE
     """
-    run_mq_command(f'echo "{mqsc_commands}" | runmqsc {args.qm_name}')
-    print(f"Queue {args.queue_name} created in queue manager {args.qm_name}.")
+    output, error = run_mq_command(f'echo "{mqsc_commands}" | runmqsc {args.qm_name}')
+    print(f"Queue {args.queue_name} created in queue manager {args.qm_name}.\n{output}")
+    if error:
+        print(f"Error: {error}")
 
 def configure_queue(args):
     """Configure an existing queue in the specified queue manager."""
     mqsc_commands = f"""
     ALTER QLOCAL('{args.queue_name}') {args.configuration}
     """
-    run_mq_command(f'echo "{mqsc_commands}" | runmqsc {args.qm_name}')
-    print(f"Queue {args.queue_name} configured in queue manager {args.qm_name} with {args.configuration}.")
+    output, error = run_mq_command(f'echo "{mqsc_commands}" | runmqsc {args.qm_name}')
+    print(f"Queue {args.queue_name} configured in queue manager {args.qm_name} with {args.configuration}.\n{output}")
+    if error:
+        print(f"Error: {error}")
 
 def start_queue_manager(args):
     """Start a queue manager."""
-    output = run_mq_command(f"/opt/mqm/bin/strmqm {args.name}")
+    output, error = run_mq_command(f"/opt/mqm/bin/strmqm {args.name}")
     print(f"Queue manager {args.name} started.\n{output}")
+    if error:
+        print(f"Error: {error}")
 
 def stop_queue_manager(args):
     """Stop a queue manager."""
-    output = run_mq_command(f"/opt/mqm/bin/endmqm -i {args.name}")
+    output, error = run_mq_command(f"/opt/mqm/bin/endmqm -i {args.name}")
     print(f"Queue manager {args.name} stopped.\n{output}")
+    if error:
+        print(f"Error: {error}")
 
 def extract_queue_names(output):
     """Extract queue names from the DISPLAY QUEUE output."""
@@ -78,7 +90,7 @@ def extract_queue_names(output):
 def display_queues(args):
     """Display all queues in the specified queue manager."""
     command = f'echo "DISPLAY QUEUE(*)" | /opt/mqm/bin/runmqsc {args.qm_name}'
-    output = run_command(command)
+    output, error = run_command(command)
     print(output)
     queue_names = extract_queue_names(output)
     for queue_name in queue_names:
@@ -89,32 +101,39 @@ def get_queue_permissions(args):
     queue_manager = args.qm_name
     user = args.user
     command = f'echo "DISPLAY QUEUE(*)" | /opt/mqm/bin/runmqsc {queue_manager}'
-    queues_output = run_command(command)
+    queues_output, _ = run_command(command)
     queue_names = extract_queue_names(queues_output)
 
     for queue_name in queue_names:
         try:
             command = f'/opt/mqm/bin/dspmqaut -m {queue_manager} -t q -n "{queue_name}" -p {user}'
-            permissions_output = run_command(command)
+            permissions_output, error = run_command(command)
             print(f"Permissions for queue '{queue_name}':\n{permissions_output}\n")
+            if error:
+                print(f"Error: {error}")
         except RuntimeError as e:
             print(f"Error fetching permissions for queue '{queue_name}': {e}")
 
 def put_message(args):
-    """Put a message on a queue in the specified queue manager."""
-    with tempfile.NamedTemporaryFile(delete=False, mode='w') as msg_file:
+    """Put a message on the specified queue."""
+    with tempfile.NamedTemporaryFile(delete=False, mode='w', suffix='.txt') as msg_file:
         msg_file.write(args.message)
         msg_file_path = msg_file.name
-    command = f'cat {msg_file_path} | /opt/mqm/samp/bin/amqsputc {args.queue_name} {args.qm_name}'
-    output = run_mq_command(command)
-    print(f"Message put on queue {args.queue_name} in queue manager {args.qm_name}.\n{output}")
+
+    mq_command = f"cat {msg_file_path} | /opt/mqm/samp/bin/amqsputc {args.queue_name} {args.qm_name}"
+    output, error = run_mq_command(mq_command)
     os.remove(msg_file_path)
+    print(output)
+    if error:
+        print(f"Error: {error}")
 
 def get_message(args):
-    """Get a message from a queue in the specified queue manager."""
-    command = f'/opt/mqm/samp/bin/amqsgetc {args.queue_name} {args.qm_name}'
-    output = run_mq_command(command)
-    print(f"Message retrieved from queue {args.queue_name} in queue manager {args.qm_name}.\n{output}")
+    """Get a message from the specified queue."""
+    mq_command = f"/opt/mqm/samp/bin/amqsgetc {args.queue_name} {args.qm_name}"
+    output, error = run_mq_command(mq_command)
+    print(output)
+    if error:
+        print(f"Error: {error}")
 
 def main():
     parser = argparse.ArgumentParser(description="IBM MQ Management CLI")
@@ -149,7 +168,7 @@ def main():
 
     # Subparser for configuring a queue
     parser_configure_queue = subparsers.add_parser("configure_queue", help="Configure a queue")
-    parser_configure_queue.add_argument("qm_name", help="Name of the queue manager")
+    parser_configure_queue.add.argument("qm_name", help="Name of the queue manager")
     parser_configure_queue.add_argument("queue_name", help="Name of the queue to configure")
     parser_configure_queue.add_argument("configuration", help="Configuration string for the queue")
     parser_configure_queue.set_defaults(func=configure_queue)
@@ -171,7 +190,7 @@ def main():
 
     # Subparser for stopping a queue manager
     parser_stop_qm = subparsers.add_parser("stop_qm", help="Stop a queue manager")
-    parser_stop_qm.add_argument("name", help="Name of the queue manager to stop")
+    parser_stop_qm.add.argument("name", help="Name of the queue manager to stop")
     parser_stop_qm.set_defaults(func=stop_queue_manager)
     parser_stop_qm.epilog = """
     Example usage:
@@ -200,22 +219,22 @@ def main():
     ibm-mq-cli get_permissions MyQueueManager anotheruser
     """
 
-    # Subparser for putting a message on a queue
-    parser_put_message = subparsers.add_parser("put_message", help="Put a message on a queue")
-    parser_put_message.add_argument("qm_name", help="Name of the queue manager")
+    # Subparser for putting a message on the queue
+    parser_put_message = subparsers.add_parser("put_message", help="Put a message on the queue")
+    parser_put_message.add.argument("qm_name", help="Name of the queue manager")
     parser_put_message.add_argument("queue_name", help="Name of the queue")
     parser_put_message.add_argument("message", help="Message to put on the queue")
     parser_put_message.set_defaults(func=put_message)
     parser_put_message.epilog = """
     Example usage:
     ibm-mq-cli put_message QM1 DEV.QUEUE.1 "Hello, World!"
-    ibm-mq-cli put_message MyQueueManager MyQueue "Test Message"
+    ibm-mq-cli put_message MyQueueManager MyQueue "Test message"
     """
 
-    # Subparser for getting a message from a queue
-    parser_get_message = subparsers.add_parser("get_message", help="Get a message from a queue")
-    parser_get_message.add_argument("qm_name", help="Name of the queue manager")
-    parser_get_message.add_argument("queue_name", help="Name of the queue")
+    # Subparser for getting a message from the queue
+    parser_get_message = subparsers.add_parser("get_message", help="Get a message from the queue")
+    parser_get_message.add.argument("qm_name", help="Name of the queue manager")
+    parser_get_message.add.argument("queue_name", help="Name of the queue")
     parser_get_message.set_defaults(func=get_message)
     parser_get_message.epilog = """
     Example usage:
